<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 * @return array An array of default values
 */

function blog_diary_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$blog_diary_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#fe463a',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Read More', 'blog-diary-pro' ),

		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'blog-diary-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'blog-diary-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'blog-diary-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage sections sortable
		'sortable' 						=> 'slider,featured_slider,latest_posts,must_read_posts,blog',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'blog-diary-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_author'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		// Top Nav
		'top_bar_nav_section_enable' 	=> true,
		'nav_search_enable'				=> true,
		'topbar_social_menu_enable'		=>true,
		'topbar_contact_number'			=> __('123 456 789','blog-diary-pro'),
		'topbar_email'					=> __('info@blogdiary.com','blog-diary-pro'),

		/* Front Page */

		// Slider
		'slider_section_enable'				=> true,
		'slider_content_type'				=> 'page',
		'slider_count'						=> 4,
		'slider_autoplay_enable'			=> false,
		'slider_btn'						=> esc_html__( 'Learn More', 'blog-diary-pro' ),

		//featured slider
		'featured_slider_section_enable'	=> true,
		'featured_slider_count'				=> 8,
		'featured_slider_btn_title'			=> esc_html__( 'Read More', 'blog-diary-pro' ),
		'featured_slider_autoplay_enable'	=> false,

		//latest Posts
		'latest_posts_section_enable'		=> true,
		'latest_posts_count'				=> 4,
		'latest_posts_title'				=> esc_html__( 'Latest Posts', 'blog-diary-pro' ),
		'latest_posts_content_type'			=> 'post',
		'latest_posts_column'				=> 4,

		//must_read Posts
		'must_read_posts_section_enable'	=> true,
		'must_read_posts_count'				=> 3,
		'must_read_posts_title'				=> esc_html__( 'Must Read Posts', 'blog-diary-pro' ),
		'must_read_posts_content_type'		=> 'post',
		'must_read_posts_column'			=> 3,	
		'must_read_posts_btn_title'			=> esc_html__( 'Read More', 'blog-diary-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 3,
		'blog_title'					=> esc_html__( 'Single Column Posts', 'blog-diary-pro' ),
		'blog_description'				=> esc_html__( 'Business consulting excepteur sint occaecat cupidatat consulting non proident, sunt in culpa qui officia deserunt laborum Market.', 'blog-diary-pro' ),
		'blog_btn_title'				=> esc_html__( 'Show All', 'blog-diary-pro' ),

		//service
		'service_section_enable'		=> true,
		'service_title'					=> esc_html__( 'The best business solutions', 'blog-diary-pro' ),
		'service_description'			=> esc_html__( 'Business consulting excepteur sint occaecat cupidatat consulting non proident, sunt in culpa qui officia deserunt laborum Market.', 'blog-diary-pro' ),
		'service_count'					=> 3,
		'service_posts_column'		=> 3,
		'service_content_type'			=> 'category',

		//video
		'video_section_enable'			=> true,
		'video_content_type'			=> 'page',
		'video_title'					=> esc_html__( 'Discover the World of Business', 'blog-diary-pro' ),
		'video_description'				=> esc_html__( 'Business consulting excepteur sint occaecat cupidatat consulting non proident, sunt in culpa qui officia deserunt laborum Market.', 'blog-diary-pro' ),

		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'About Company', 'blog-diary-pro' ),
		'about_description'				=> esc_html__( 'Lorem ipsum dolor sit amet, con sectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libLorem ipsum dolor sit amet, consectetur adipiscing elit. Etiam euismod pulvinar velit id commodo. Aenean id varius libero. Curabitur sit amet eros velit. Fusce sed cursus quam. Nam sit amet sapien eu lorem fringilla ullamcorper. Integer fermentum erat gravida, sagittis quam in, condimentum ligula.', 'blog-diary-pro' ),

		// Counter
		'counter_section_enable'		=> true,

		// team
		'team_section_enable'		=> true,
		'team_content_type'			=> 'category',
		'team_count'					=> 4,
		'team_title'					=> esc_html__( 'Our Team Members.', 'blog-diary-pro' ),
		'team_description'				=> esc_html__( 'Business consulting excepteur sint occaecat cupidatat consulting non proident, sunt in culpa qui officia deserunt laborum Market.', 'blog-diary-pro' ),

		//subscription
		'subscription_section_enable'			=> false,
		'subscription_sub_title'				=> esc_html__( 'Newsletter', 'blog-diary-pro' ),
		'subscription_title'					=> esc_html__( 'Get In Touch', 'blog-diary-pro' ),
		'subscription_btn_title'				=> esc_html__( 'Subscribe Now', 'blog-diary-pro' ),

		// popular destination
		'popular_destination_section_enable'	=> true,
		'popular_destination_content_type'		=> 'category',
		'popular_destination_count'				=> 5,
		'popular_destination_title'				=> esc_html__( 'Popular Destinations', 'blog-diary-pro' ),
		'popular_destination_read_more'			=> esc_html__( 'Read More', 'blog-diary-pro' ),
		'popular_destination_btn_title'			=> esc_html__( 'View All Popular Destinations', 'blog-diary-pro' ),

		// popular tours
		'popular_tours_section_enable'	=> true,
		'popular_tours_content_type'		=> 'category',
		'popular_tours_count'				=> 3,
		'popular_tours_title'				=> esc_html__( 'Popular Tours', 'blog-diary-pro' ),
		'popular_tours_btn_title'			=> esc_html__( 'View All Popular Tours', 'blog-diary-pro' ),

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_title'				=> esc_html__( 'Customer Reviews', 'blog-diary-pro' ),
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 3,

		// Event
		'event_section_enable'			=> true,
		'event_content_type'			=> 'category',
		'event_count'					=> 4,
		'event_title'					=> esc_html__( 'Upcoming Events', 'blog-diary-pro' ),
		'event_description'				=> esc_html__( 'Although “music that you like” should be given preference, most people have a fairly wide range of tastes, so using a certain type of music just for work isn’t out of the question.', 'blog-diary-pro' ),
		'event_readmore'				=> esc_html__( 'Buy Ticket', 'blog-diary-pro' ),
		'event_btn_title'				=> esc_html__( 'EXPLORE MORE', 'blog-diary-pro' ),

		//cta
		'cta_section_enable'			=> true,
		'cta_content_type'				=> 'page',
		'cta_title'						=> esc_html__( 'CALL TO ACTION', 'blog-diary-pro' ),
		'cta_button'					=> esc_html__( 'LEARN MORE', 'blog-diary-pro' ),
		'cta_description'				=> esc_html__( 'Although “music that you like” should be given preference, most people have a fairly wide range of tastes, so using a certain type of music just for work isn’t out of the question.', 'blog-diary-pro' ),

		// release
		'release_section_enable'		=> true,
		'release_content_type'			=> 'category',
		'release_count'					=> 3,
		'release_title'					=> esc_html__( 'NEW RELEASES', 'blog-diary-pro' ),
		'release_btn_title'				=> esc_html__( 'LEARN MORE', 'blog-diary-pro' ),
		'release_description'			=> esc_html__( 'Although “music that you like” should be given preference, most people have a fairly wide range of tastes, so using a certain type of music just for work isn’t out of the question.', 'blog-diary-pro' ),

		'recent_product_section_enable'		=> true,
		'recent_product_content_type'		=> 'product',
		'recent_product_count'				=> 4,
		'recent_product_title'				=> esc_html__( 'FEATURED PRODUCTS', 'blog-diary-pro' ),
		'recent_product_sub_title'			=> esc_html__( 'All Styles in This Spring', 'blog-diary-pro' ),

		//masonry section
		'masonry_section_enable'		=> false,

		//featured section
		'featured_section_enable'		=> false,

	);

	$output = apply_filters( 'blog_diary_pro_default_theme_options', $blog_diary_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}