<?php
/**
 * Blog Section options
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */

// Add Blog section
$wp_customize->add_section( 'blog_diary_pro_blog_section', array(
    'title'             => esc_html__( 'Blog','blog-diary-pro' ),
    'description'       => esc_html__( 'Blog Section options.', 'blog-diary-pro' ),
    'panel'             => 'blog_diary_pro_front_page_panel',
) );

// Blog content enable control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[blog_section_enable]', array(
    'default'           =>  $options['blog_section_enable'],
    'sanitize_callback' => 'blog_diary_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Blog_Diary_Pro_Switch_Control( $wp_customize, 'blog_diary_pro_theme_options[blog_section_enable]', array(
    'label'             => esc_html__( 'Blog Section Enable', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_blog_section',
    'on_off_label'      => blog_diary_pro_switch_options(),
) ) );

if( $options['home_layout'] == 'fourth-design' ):

// ads image setting and control.
$wp_customize->add_setting( 'blog_diary_pro_theme_options[ads_image]', array(
    'sanitize_callback' => 'blog_diary_pro_sanitize_image'
    ) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'blog_diary_pro_theme_options[ads_image]',
    array(
        'label'             => esc_html__( 'Ads Image', 'blog-diary-pro' ),
        'description'       => sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'blog-diary-pro' ), 1143, 89 ),
        'section'           => 'blog_diary_pro_blog_section',
        'active_callback'   => 'blog_diary_pro_is_blog_section_enable',
        ) ) );

// ads link setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[ads_url]', array(
    'sanitize_callback' => 'esc_url_raw',
    ) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[ads_url]', array(
    'label'             => esc_html__( 'Ads Url', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_blog_section',
    'active_callback'   => 'blog_diary_pro_is_blog_section_enable',
    'type'              => 'url',
    ) );

endif;

// blog title setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[blog_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['blog_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[blog_title]', array(
    'label'             => esc_html__( 'Title', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_blog_section',
    'active_callback'   => 'blog_diary_pro_is_blog_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'blog_diary_pro_theme_options[blog_title]', array(
        'selector'            => '#blog .archive-blog-wrapper .section-header h2.section-title',
        'settings'            => 'blog_diary_pro_theme_options[blog_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'blog_diary_pro_blog_title_partial',
    ) );
}

if( $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fifth-design' || $options['home_layout'] == 'seventh-design' || $options['home_layout'] == 'eight-design' || $options['home_layout'] == 'nine-design' ):

// blog description setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[blog_description]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['blog_description'],
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[blog_description]', array(
    'label'             => esc_html__( 'Description', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_blog_section',
    'active_callback'   => 'blog_diary_pro_is_blog_section_enable',
    'type'              => 'textarea',
) );

endif;

// Event social icons number control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[blog_count]', array(
    'default'           => $options['blog_count'],
    'sanitize_callback' => 'blog_diary_pro_sanitize_number_range',
    'validate_callback' => 'blog_diary_pro_validate_blog_count',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[blog_count]', array(
    'label'             => esc_html__( 'Number of Posts', 'blog-diary-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_blog_section',
    'active_callback'   => 'blog_diary_pro_is_blog_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 10,
        'style' => 'width: 100px;'
        ),
) );

// Blog content type control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[blog_content_type]', array(
    'default'           => $options['blog_content_type'],
    'sanitize_callback' => 'blog_diary_pro_sanitize_select',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[blog_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_blog_section',
    'type'              => 'select',
    'active_callback'   => 'blog_diary_pro_is_blog_section_enable',
    'choices'           => array( 
        'page'      => esc_html__( 'Page', 'blog-diary-pro' ),
        'post'      => esc_html__( 'Post', 'blog-diary-pro' ),
        'category'  => esc_html__( 'Category', 'blog-diary-pro' ),
        'recent'    => esc_html__( 'Recent', 'blog-diary-pro' ),
    ),
) );

for ( $i = 1; $i <= $options['blog_count']; $i++ ) :
    // blog pages drop down chooser control and setting
    $wp_customize->add_setting( 'blog_diary_pro_theme_options[blog_content_page_' . $i . ']', array(
        'sanitize_callback' => 'blog_diary_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Blog_Diary_Pro_Dropdown_Chooser( $wp_customize, 'blog_diary_pro_theme_options[blog_content_page_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Page %d', 'blog-diary-pro' ), $i ),
        'section'           => 'blog_diary_pro_blog_section',
        'choices'           => blog_diary_pro_page_choices(),
        'active_callback'   => 'blog_diary_pro_is_blog_section_content_page_enable',
    ) ) );

    // blog posts drop down chooser control and setting
    $wp_customize->add_setting( 'blog_diary_pro_theme_options[blog_content_post_' . $i . ']', array(
        'sanitize_callback' => 'blog_diary_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Blog_Diary_Pro_Dropdown_Chooser( $wp_customize, 'blog_diary_pro_theme_options[blog_content_post_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Post %d', 'blog-diary-pro' ), $i ),
        'section'           => 'blog_diary_pro_blog_section',
        'choices'           => blog_diary_pro_post_choices(),
        'active_callback'   => 'blog_diary_pro_is_blog_section_content_post_enable',
    ) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'blog_diary_pro_theme_options[blog_content_category]', array(
    'sanitize_callback' => 'blog_diary_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Blog_Diary_Pro_Dropdown_Taxonomies_Control( $wp_customize,'blog_diary_pro_theme_options[blog_content_category]', array(
    'label'             => esc_html__( 'Select Category', 'blog-diary-pro' ),
    'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_blog_section',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'blog_diary_pro_is_blog_section_content_category_enable'
) ) );

// Add dropdown categories setting and control.
$wp_customize->add_setting( 'blog_diary_pro_theme_options[blog_category_exclude]', array(
    'sanitize_callback' => 'blog_diary_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Blog_Diary_Pro_Dropdown_Multiple_Chooser( $wp_customize,'blog_diary_pro_theme_options[blog_category_exclude]', array(
    'label'             => esc_html__( 'Select Excluding Categories', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_blog_section',
    'type'              => 'dropdown_multiple_chooser',
    'choices'           =>  blog_diary_pro_category_choices(),
    'active_callback'   => 'blog_diary_pro_is_blog_section_content_recent_enable'
) ) );

// blog btn title setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[blog_btn_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['blog_btn_title'],
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[blog_btn_title]', array(
    'label'             => esc_html__( 'Button Label', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_blog_section',
    'active_callback'   => 'blog_diary_pro_is_blog_section_enable',
    'type'              => 'text',
) );

if( $options['home_layout'] == 'sixth-design' ):

// blog btn url setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[blog_btn_url]', array(
    'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[blog_btn_url]', array(
    'label'             => esc_html__( 'Button Link', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_blog_section',
    'active_callback'   => 'blog_diary_pro_is_blog_section_enable',
    'type'              => 'url',
) );

endif;
