<?php
/**
 * CTA Section options
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */

// Add CTA section
$wp_customize->add_section( 'blog_diary_pro_cta_section', array(
	'title'             => esc_html__( 'CTA','blog-diary-pro' ),
	'description'       => esc_html__( 'CTA Section options.', 'blog-diary-pro' ),
	'panel'             => 'blog_diary_pro_front_page_panel',
) );

// CTA content enable control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[cta_section_enable]', array(
	'default'			=> 	$options['cta_section_enable'],
	'sanitize_callback' => 'blog_diary_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Blog_Diary_Pro_Switch_Control( $wp_customize, 'blog_diary_pro_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'CTA Section Enable', 'blog-diary-pro' ),
	'section'           => 'blog_diary_pro_cta_section',
	'on_off_label' 		=> blog_diary_pro_switch_options(),
) ) );

// cta number control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[cta_image]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'blog_diary_pro_theme_options[cta_image]', array(
	'label'             => esc_html__( 'Background Image', 'blog-diary-pro' ),
	'section'           => 'blog_diary_pro_cta_section',
	'active_callback'   => 'blog_diary_pro_is_cta_section_enable',
) ) );

// CTA content type control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[cta_content_type]', array(
	'default'          	=> $options['cta_content_type'],
	'sanitize_callback' => 'blog_diary_pro_sanitize_select',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[cta_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'blog-diary-pro' ),
	'section'           => 'blog_diary_pro_cta_section',
	'type'				=> 'select',
	'active_callback' 	=> 'blog_diary_pro_is_cta_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'blog-diary-pro' ),
		'post' 		=> esc_html__( 'Post', 'blog-diary-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'blog-diary-pro' ),
	),
) );

// cta pages drop down chooser control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[cta_content_page]', array(
	'sanitize_callback' => 'blog_diary_pro_sanitize_page',
) );

$wp_customize->add_control( new Blog_Diary_Pro_Dropdown_Chooser( $wp_customize, 'blog_diary_pro_theme_options[cta_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'blog-diary-pro' ),
	'section'           => 'blog_diary_pro_cta_section',
	'choices'			=> blog_diary_pro_page_choices(),
	'active_callback'	=> 'blog_diary_pro_is_cta_section_content_page_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[cta_content_post]', array(
	'sanitize_callback' => 'blog_diary_pro_sanitize_page',
) );

$wp_customize->add_control( new Blog_Diary_Pro_Dropdown_Chooser( $wp_customize, 'blog_diary_pro_theme_options[cta_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'blog-diary-pro' ),
	'section'           => 'blog_diary_pro_cta_section',
	'choices'			=> blog_diary_pro_post_choices(),
	'active_callback'	=> 'blog_diary_pro_is_cta_section_content_post_enable',
) ) );

// cta title setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[cta_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_title'],
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[cta_title]', array(
	'label'           	=> esc_html__( 'Title', 'blog-diary-pro' ),
	'section'        	=> 'blog_diary_pro_cta_section',
	'active_callback' 	=> 'blog_diary_pro_is_cta_section_content_custom_enable',
	'type'				=> 'text',
) );

// cta description setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[cta_description]', array(
	'sanitize_callback' => 'wp_kses_post',
	'default'			=> $options['cta_description'],
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[cta_description]', array(
	'label'           	=> esc_html__( 'Description', 'blog-diary-pro' ),
	'section'        	=> 'blog_diary_pro_cta_section',
	'active_callback' 	=> 'blog_diary_pro_is_cta_section_content_custom_enable',
	'type'				=> 'textarea',
) );

// cta title setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[cta_button]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_button'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[cta_button]', array(
	'label'           	=> esc_html__( 'Button', 'blog-diary-pro' ),
	'section'        	=> 'blog_diary_pro_cta_section',
	'active_callback' 	=> 'blog_diary_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'blog_diary_pro_theme_options[cta_button]', array(
		'selector'            => '#music-cta div.music-read-more a',
		'settings'            => 'blog_diary_pro_theme_options[cta_button]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'blog_diary_pro_cta_button_partial',
    ) );
}

// cta btn link setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[button_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[button_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'blog-diary-pro' ),
	'section'        	=> 'blog_diary_pro_cta_section',
	'active_callback' 	=> 'blog_diary_pro_is_cta_section_content_custom_enable',
	'type'				=> 'url',
) );