<?php
/**
 * recent_product Section options
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */
if ( !class_exists('WooCommerce') ) {
    return;
}

// Add recent_product section
$wp_customize->add_section( 'blog_diary_pro_recent_product_section', array(
    'title'             => esc_html__( 'Recent Product','blog-diary-pro' ),
    'description'       => esc_html__( 'Recent Product Section options.', 'blog-diary-pro' ),
    'panel'             => 'blog_diary_pro_front_page_panel',
) );

// recent_product content enable control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[recent_product_section_enable]', array(
    'default'           =>  $options['recent_product_section_enable'],
    'sanitize_callback' => 'blog_diary_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Blog_Diary_Pro_Switch_Control( $wp_customize, 'blog_diary_pro_theme_options[recent_product_section_enable]', array(
    'label'             => esc_html__( 'Recent product Section Enable', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_recent_product_section',
    'on_off_label'      => blog_diary_pro_switch_options(),
) ) );

// recent_product title setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[recent_product_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['recent_product_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[recent_product_title]', array(
    'label'             => esc_html__( 'Title', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_recent_product_section',
    'active_callback'   => 'blog_diary_pro_is_recent_product_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'blog_diary_pro_theme_options[recent_product_title]', array(
        'selector'            => '#recent-products h2.section-title',
        'settings'            => 'blog_diary_pro_theme_options[recent_product_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'blog_diary_pro_recent_product_title_partial',
    ) );
}

// recent_product title setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[recent_product_sub_title]', array(
    'sanitize_callback' => 'sanitize_text_field',
    'default'           => $options['recent_product_sub_title'],
    'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[recent_product_sub_title]', array(
    'label'             => esc_html__( 'Sub Title', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_recent_product_section',
    'active_callback'   => 'blog_diary_pro_is_recent_product_section_enable',
    'type'              => 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'blog_diary_pro_theme_options[recent_product_sub_title]', array(
        'selector'            => '#recent-products p.subtitle',
        'settings'            => 'blog_diary_pro_theme_options[recent_product_sub_title]',
        'container_inclusive' => false,
        'fallback_refresh'    => true,
        'render_callback'     => 'blog_diary_pro_recent_product_sub_title_partial',
    ) );
}

$wp_customize->add_setting( 'blog_diary_pro_theme_options[recent_product_count]', array(
    'default'           => $options['recent_product_count'],
    'sanitize_callback' => 'blog_diary_pro_sanitize_number_range',
    'validate_callback' => 'blog_diary_pro_validate_recent_product_count',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[recent_product_count]', array(
    'label'             => esc_html__( 'Number of Product', 'blog-diary-pro' ),
    'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_recent_product_section',
    'active_callback'   => 'blog_diary_pro_is_recent_product_section_enable',
    'type'              => 'number',
    'input_attrs'       => array(
        'min'   => 1,
        'max'   => 12,
        'style' => 'width: 100px;'
        ),
) );

$wp_customize->add_setting( 'blog_diary_pro_theme_options[recent_product_content_type]', array(
    'default'           => $options['recent_product_content_type'],
    'sanitize_callback' => 'blog_diary_pro_sanitize_select',
) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[recent_product_content_type]', array(
    'label'             => esc_html__( 'Content Type', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_recent_product_section',
    'type'              => 'select',
    'active_callback'   => 'blog_diary_pro_is_recent_product_section_enable',
    'choices'           => blog_diary_pro_recent_product_options(),
) );

for( $i = 1 ; $i <= $options['recent_product_count'] ; $i++ ){

    $wp_customize->add_setting( 'blog_diary_pro_theme_options[recent_product_content_page_' . $i . ']', array(
        'sanitize_callback' => 'blog_diary_pro_sanitize_page',
    ) );

    $wp_customize->add_control( new Blog_Diary_Pro_Dropdown_Chooser( $wp_customize, 'blog_diary_pro_theme_options[recent_product_content_page_' . $i . ']', array(
        'label'             => sprintf( esc_html__( 'Select Product %d', 'blog-diary-pro' ), $i ),
        'section'           => 'blog_diary_pro_recent_product_section',
        'choices'           => blog_diary_pro_product_choices(),
        'active_callback'   => 'blog_diary_pro_is_recent_product_section_content_product_enable',
    ) ) );
}

// Add dropdown category setting and control.
$wp_customize->add_setting(  'blog_diary_pro_theme_options[product_content_recent_product_category]', array(
    'sanitize_callback' => 'absint',
) ) ;

$wp_customize->add_control( new Blog_Diary_Pro_Dropdown_Taxonomies_Control( $wp_customize,'blog_diary_pro_theme_options[product_content_recent_product_category]', array(
    'label'             => esc_html__( 'Select Product Category', 'blog-diary-pro' ),
    'description'       => esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_recent_product_section',
    'taxonomy'          => 'product_cat',
    'type'              => 'dropdown-taxonomies',
    'active_callback'   => 'blog_diary_pro_is_recent_product_section_content_product_category_enable'
) ) );