<?php
/**
 * Secondary Nav Section options
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */

// Add Secondary Nav section
$wp_customize->add_section( 'blog_diary_pro_secondary_nav_section', array(
	'title'             => esc_html__( 'Top Bar Nav','blog-diary-pro' ),
	'description'       => esc_html__( 'Top Bar Nav Section options.', 'blog-diary-pro' ),
	'panel'             => 'blog_diary_pro_front_page_panel',
) );

// Secondary Nav content enable control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[top_bar_nav_section_enable]', array(
	'default'			=> 	$options['top_bar_nav_section_enable'],
	'sanitize_callback' => 'blog_diary_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Blog_Diary_Pro_Switch_Control( $wp_customize, 'blog_diary_pro_theme_options[top_bar_nav_section_enable]', array(
	'label'             => esc_html__( 'Secondary Nav Section Enable', 'blog-diary-pro' ),
	'description'       => sprintf( '%1$s <a target="_blank" href="' . esc_url( admin_url( 'nav-menus.php' ) ) . '"> %2$s </a> %3$s', esc_html__( 'Note: Make sure you have created Menu and asigned to Secondary Location. If you have not to show menu.', 'blog-diary-pro' ), esc_html__( 'Click Here', 'blog-diary-pro' ), esc_html__( 'to create menu', 'blog-diary-pro' ) ),
	'section'           => 'blog_diary_pro_secondary_nav_section',
	'on_off_label' 		=> blog_diary_pro_switch_options(),
) ) );

if( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'second-design' || $options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'sixth-design' ):
// Top Nav Search content enable control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[nav_search_enable]', array(
	'default'			=> 	$options['nav_search_enable'],
	'sanitize_callback' => 'blog_diary_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Blog_Diary_Pro_Switch_Control( $wp_customize, 'blog_diary_pro_theme_options[nav_search_enable]', array(
	'label'             => esc_html__( 'Secondary Nav Search Enable', 'blog-diary-pro' ),
	'section'           => 'blog_diary_pro_secondary_nav_section',
	'on_off_label' 		=> blog_diary_pro_switch_options(),
	'active_callback'   => 'blog_diary_pro_is_secondary_nav_section_enable',
) ) );

endif;

if( $options['home_layout'] == 'fourth-design' || $options['home_layout'] == 'sixth-design' ):

// ads image setting and control.
$wp_customize->add_setting( 'blog_diary_pro_theme_options[advertisement_image]', array(
    'sanitize_callback' => 'blog_diary_pro_sanitize_image'
    ) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'blog_diary_pro_theme_options[advertisement_image]',
    array(
        'label'             => esc_html__( 'Advertisement Image', 'blog-diary-pro' ),
        'description'       => sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'blog-diary-pro' ), 400, 40 ),
        'section'           => 'blog_diary_pro_secondary_nav_section',
        'active_callback'   => 'blog_diary_pro_is_secondary_nav_section_enable',
        ) ) );

// ads link setting and control
$wp_customize->add_setting( 'blog_diary_pro_theme_options[advertisement_url]', array(
    'sanitize_callback' => 'esc_url_raw',
    ) );

$wp_customize->add_control( 'blog_diary_pro_theme_options[advertisement_url]', array(
    'label'             => esc_html__( 'Advertisement Url', 'blog-diary-pro' ),
    'section'           => 'blog_diary_pro_secondary_nav_section',
    'active_callback'   => 'blog_diary_pro_is_secondary_nav_section_enable',
    'type'              => 'url',
    ) );

endif;

if( $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fifth-design' || $options['home_layout'] == 'seventh-design' || $options['home_layout'] == 'eight-design' || $options['home_layout'] == 'nine-design' ):
    
// Topbar Social menu  enable control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[topbar_social_menu_enable]', array(
	'default'			=> 	$options['topbar_social_menu_enable'],
	'sanitize_callback' => 'blog_diary_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Blog_Diary_Pro_Switch_Control( $wp_customize, 'blog_diary_pro_theme_options[topbar_social_menu_enable]', array(
	'label'             => esc_html__( 'Enable Social menu', 'blog-diary-pro' ),
	'description'       => sprintf( '%1$s <a class="topbar-menu-trigger" href="#"> %2$s </a> %3$s', esc_html__( 'Note: To show social menu.', 'blog-diary-pro' ), esc_html__( 'Click Here', 'blog-diary-pro' ), esc_html__( 'to create menu', 'blog-diary-pro' ) ),
	'section'           => 'blog_diary_pro_secondary_nav_section',
	'active_callback' 	=> 'blog_diary_pro_is_secondary_nav_section_enable',
	'on_off_label' 		=> blog_diary_pro_switch_options(),
) ) );

// Topbar contact number control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[topbar_contact_number]', array(
	'default'			=> $options['topbar_contact_number'],
    'sanitize_callback' => 'sanitize_text_field',
) );
    
$wp_customize->add_control( 'blog_diary_pro_theme_options[topbar_contact_number]', array(
    'label'           	=> esc_html__( 'Contact Number', 'blog-diary-pro' ),
    'section'        	=> 'blog_diary_pro_secondary_nav_section',
    'active_callback' 	=> 'blog_diary_pro_is_secondary_nav_section_enable',
    'type'				=> 'text',
) );

// Topbar contact email control and setting
$wp_customize->add_setting( 'blog_diary_pro_theme_options[topbar_email]', array(
	'default'			=> $options['topbar_email'],
    'sanitize_callback' => 'sanitize_email',
    ) );
    
$wp_customize->add_control( 'blog_diary_pro_theme_options[topbar_email]', array(
    'label'           	=> esc_html__( 'Email', 'blog-diary-pro' ),
    'section'        	=> 'blog_diary_pro_secondary_nav_section',
    'active_callback' 	=> 'blog_diary_pro_is_secondary_nav_section_enable',
    'type'				=> 'email',
) );

endif;
