<?php
/**
 * About section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */
if ( ! function_exists( 'blog_diary_pro_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Blog Diary Pro 1.0.0
    */
    function blog_diary_pro_add_about_section() {
    	$options = blog_diary_pro_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'blog_diary_pro_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'blog_diary_pro_filter_about_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render about section now.
        blog_diary_pro_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'blog_diary_pro_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Blog Diary Pro 1.0.0
    * @param array $input about section details.
    */
    function blog_diary_pro_get_about_section_details( $input ) {
        $options = blog_diary_pro_get_theme_options();

        // Content type.
        $about_content_type  = $options['about_content_type'];
        
        $content = array();
        switch ( $about_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['about_title'] ) ? $options['about_title'] : '';
                $custom['excerpt']      = ! empty( $options['about_description'] ) ? $options['about_description'] : '';
                $custom['image']        = ! empty( $options['about_image'] ) ? $options['about_image'] : '';
                $custom['url']          = ! empty( $options['about_btn_link'] ) ? $options['about_btn_link'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['about_content_page'] ) ? $options['about_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['about_content_post'] ) ? $options['about_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $about_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = blog_diary_pro_trim_content( 50 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'blog_diary_pro_filter_about_section_details', 'blog_diary_pro_get_about_section_details' );


if ( ! function_exists( 'blog_diary_pro_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Blog Diary Pro 1.0.0
   *
   */
   function blog_diary_pro_render_about_section( $content_details = array() ) {
        $options = blog_diary_pro_get_theme_options();
        $readmore = ! empty( $options['about_btn_title'] ) ? $options['about_btn_title'] : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <?php if ( $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fifth-design' || $options['home_layout'] == 'eight-design' || $options['home_layout'] == 'nine-design' ): ?>
        <div id="business-about-us" class="relative page-section">
            <div class="wrapper">
            <?php foreach ( $content_details as $content ) :  ?>
                <article class="has-post-thumbnail">
                <?php if ( ! empty( $content['image'] ) ) : ?>
                    <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                        <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                    </div><!-- .featured-image -->
                <?php endif; ?>
                    <div class="entry-container">
                    <?php if ( ! empty( $content['title'] ) ) : ?>
                        <header class="entry-header">
                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                        </header>
                    <?php endif; ?>

                     <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                        <div class="entry-content">
                            <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                        </div><!-- .entry-content -->
                    <?php endif; ?>

                    <?php if ( ! empty( $content['url'] ) && !empty( $readmore ) ) : ?>
                        <div class="<?php echo ($options['home_layout'] !== 'fifth-design') ? 'business' : 'music' ?>-read-more">
                            <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $readmore ); ?></a>
                        </div><!-- .business-read-more -->
                    <?php endif; ?>
                    </div><!-- .entry-container -->
                </article>
            <?php endforeach; ?>
            </div><!-- .wrapper -->
        </div>

    <?php endif; ?>

<?php    }
endif;
          