<?php
/**
 * recent_product section
 *
 * This is the template for the content of recent_product section
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */
if ( ! function_exists( 'blog_diary_pro_add_recent_product_section' ) ) :
    /**
    * Add recent_product section
    *
    *@since Blog Diary Pro 1.0.0
    */
    function blog_diary_pro_add_recent_product_section() {
    	$options = blog_diary_pro_get_theme_options();
        // Check if recent_product is enabled on frontpage
        $recent_product_enable = apply_filters( 'blog_diary_pro_section_status', true, 'recent_product_section_enable' );

        if ( true !== $recent_product_enable ) {
            return false;
        }
        // Get recent_product section details
        $section_details = array();
        $section_details = apply_filters( 'blog_diary_pro_filter_recent_product_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        if ( !class_exists('WooCommerce') ) {
            return;
        }
        // Render recent_product section now.
        blog_diary_pro_render_recent_product_section( $section_details );
    }
endif;

if ( ! function_exists( 'blog_diary_pro_get_recent_product_section_details' ) ) :
    /**
    * recent_product section details.
    *
    * @since Blog Diary Pro 1.0.0
    * @param array $input recent_product section details.
    */
    function blog_diary_pro_get_recent_product_section_details( $input ) {
        $options = blog_diary_pro_get_theme_options();

        // Content type.
        $recent_product_content_type  = $options['recent_product_content_type'];     
        $recent_product_count = ! empty( $options['recent_product_count'] ) ? $options['recent_product_count'] : 4;
        $recent_product_event_count = ! empty( $options['recent_product_event_count'] ) ? $options['recent_product_event_count'] : 4;
        
        $content = array();
        $content = array();
        switch ( $recent_product_content_type ) {

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $recent_product_count; $i++ ) {
                    if ( ! empty( $options['recent_product_content_page_' . $i] ) )
                        $page_ids[] = $options['recent_product_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $recent_product_count ),
                    'orderby'           => 'post__in',
                    );
            break;
            case 'product-cat':
                $cat_id = ! empty( $options['product_content_recent_product_category'] ) ? $options['product_content_recent_product_category'] : '';

                $args = array(
                'post_type'         => 'product',
                'posts_per_page'    => absint( $recent_product_count ),
                'tax_query'         => array(
                    array(
                        'taxonomy'  => 'product_cat',
                        'field'     => 'id',
                        'terms'     => $cat_id
                    )
                ) );
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = blog_diary_pro_trim_content( 20 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// recent_product section content details.
add_filter( 'blog_diary_pro_filter_recent_product_section_details', 'blog_diary_pro_get_recent_product_section_details' );


if ( ! function_exists( 'blog_diary_pro_render_recent_product_section' ) ) :
  /**
   * Start recent_product section
   *
   * @return string recent_product content
   * @since Blog Diary Pro 1.0.0
   *
   */
   function blog_diary_pro_render_recent_product_section( $content_details = array() ) {
        $options = blog_diary_pro_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
      
        <div id="recent-products" class="relative page-section same-background">
            <div class="wrapper">
                <div class="section-header">
                <?php if( !empty( $options['recent_product_sub_title'] ) ): ?>
                    <p class="subtitle"><?php echo esc_html( $options['recent_product_sub_title'] ) ?></p>
                <?php endif;

                if( !empty( $options['recent_product_title'] ) ): ?>
                    <h2 class="section-title"><?php echo esc_html( $options['recent_product_title'] ) ?></h2>
                <?php endif; ?>
                </div><!-- .section-header -->

                <div class="section-content">
                    <ul class="products col-4">

                     <?php foreach ( $content_details as $content ): ?>

                        <li class="product featured-products">
                            <a href="<?php echo esc_url( $content['url'] ) ; ?>" class="woocommerce-LoopProduct-link woocommerce-loop-product__link">
                                <?php 
                                $product = new WC_Product( $content['id'] );
                                if ( $product->get_sale_price() ): 
                                    ?>
                                <span class="onsale">
                                    <?php esc_html_e('Sale!', 'blog-diary-pro'); ?>
                                </span>
                            <?php endif ?>
                                <img src="<?php echo esc_url( $content['image'] ) ?>">
                                <h2 class="woocommerce-loop-product__title"><?php echo esc_html( $content['title'] ) ?></h2>
                                <span class="price">
                                    <ins><span class="woocommerce-Price-amount amount"><span class="woocommerce-Price-currencySymbol">
                                        <?php 
                                        $product = new WC_Product( $content['id'] );
                                        echo $product->get_price_html();
                                        ?>
                                    </ins>
                                </span>
                            </a>
                        </li>

                         <?php endforeach ?>

                    </ul><!-- .product-slider -->
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div>

    <?php }
endif;