<?php
/**
 * Banner section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */
if ( ! function_exists( 'blog_diary_pro_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since Blog Diary Pro 1.0.0
    */
    function blog_diary_pro_add_slider_section() {
    	$options = blog_diary_pro_get_theme_options();
        // Check if slider is enabled on frontpage
        $slider_enable = apply_filters( 'blog_diary_pro_section_status', true, 'slider_section_enable' );

        if ( true !== $slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'blog_diary_pro_filter_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render slider section now.
        blog_diary_pro_render_slider_section( $section_details );
    }
endif;

if ( ! function_exists( 'blog_diary_pro_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since Blog Diary Pro 1.0.0
    * @param array $input slider section details.
    */
    function blog_diary_pro_get_slider_section_details( $input ) {
        $options = blog_diary_pro_get_theme_options();

        // Content type.
        $slider_content_type  = $options['slider_content_type'];
        $slider_count = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 4;
        
        $content = array();
        switch ( $slider_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_page_' . $i] ) )
                        $page_ids[] = $options['slider_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_post_' . $i] ) )
                        $post_ids[] = $options['slider_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['slider_category'] ) ? $options['slider_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $slider_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'product':
                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_product_' . $i] ) )
                        $page_ids[] = $options['slider_content_product_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'product',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'product-category':
                $cat_id = ! empty( $options['slider_content_product_category'] ) ? $options['slider_content_product_category'] : '';
                $args = array(
                    'post_type'      => 'product',
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'product_cat',
                            'field'    => 'id',
                            'terms'    => $cat_id,
                        ),
                    ),
                    'posts_per_page'  => absint( $slider_count ),
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = blog_diary_pro_trim_content( 20 );
                $page_post['url']       = get_the_permalink();
                $page_post['author']    = blog_diary_pro_author();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'blog_diary_pro_filter_slider_section_details', 'blog_diary_pro_get_slider_section_details' );


if ( ! function_exists( 'blog_diary_pro_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since Blog Diary Pro 1.0.0
   *
   */
   function blog_diary_pro_render_slider_section( $content_details = array() ) {
        $options = blog_diary_pro_get_theme_options();
        $slider_content_type  = $options['slider_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        
        <?php if ( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'second-design' || $options['home_layout'] == 'fourth-design' ): ?>

        <div id="featured-slider" class="relative modern-slider" data-slick='{"slidesToShow":<?php echo ( $options['home_layout'] == 'fourth-design' ) ? '3' : '1';?>, "slidesToScroll": 1, "infinite": true, "speed": 500, "dots": false, "arrows":true, "autoplay": <?php echo $options['slider_autoplay_enable'] ? 'true': 'false'; ?>, "draggable": true, "fade": false }'>
            <?php 
                $i=1;
                foreach ( $content_details as $content ) : ?>
                    <article style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');" class="<?php echo ($i==1) ? 'display-block' : 'display-none';?>">
                        <div class="entry-container">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-meta">
                                <?php 
                                    echo wp_kses_post( $content['author'] );
                                    blog_diary_pro_posted_on( $content['id'] ); 
                                    if ( 'page' !== $slider_content_type ) : ?>
                                        <span class="cat-links">
                                            <?php the_category( '', '', $content['id'] ); ?>
                                        </span><!-- .cat-links -->
                                <?php endif; ?> 

                            </div><!-- .entry-meta -->
                        </div><!-- .entry-container -->
                    </article>
            <?php 
                $i++;
                endforeach; ?>
       </div><!-- #featured-slider -->

   <?php endif; ?>

   <?php if ( $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fifth-design' || $options['home_layout'] == 'seventh-design' || $options['home_layout'] == 'eight-design'|| $options['home_layout'] == 'nine-design' ): ?>

            <div id="business-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": true, "arrows":false, "autoplay": <?php echo $options['slider_autoplay_enable'] ? 'true': 'false'; ?>, "draggable": true, "fade": false, "adaptiveHeight": true }'>

            <?php foreach ( $content_details as $content ) : ?>
                
                <article style="background-image:url('<?php echo esc_url( $content['image'] ); ?>');">
                    <div class="overlay"></div>
                    <div class="wrapper">
                        <div class="business-slider-wrapper">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content-->
                            <?php if(!empty( $content['url'] ) && !empty( $options['slider_btn'] ) ): ?>
                            <div class="business-read-more">
                                <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $options['slider_btn'] ); ?></a>
                            </div><!-- .business-read-more -->
                        <?php endif; ?>
                        </div><!-- .business-slider-wrapper -->
                    </div><!-- .wrapper -->
                </article>

            <?php endforeach; ?>

            </div>

   <?php endif; ?>

   <?php if ( $options['home_layout'] == 'sixth-design' ): ?>

    <div id="travel-slider" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1500, "dots": false, "arrows":true, "autoplay": <?php echo $options['slider_autoplay_enable'] ? 'true': 'false'; ?>, "draggable": true, "fade": false }'>

    <?php foreach ( $content_details as $content ) : ?>

        <article style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
            <div class="overlay"></div>
            <div class="travel-content-wrapper">
                <header class="entry-header">
                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                </header>

                <div class="entry-content">
                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                </div><!-- .entry-content -->
                <?php if(!empty( $content['url'] ) && !empty( $options['slider_btn'] ) ): ?>
                <div class="read-more">
                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn btn-primary"><?php echo esc_html( $options['slider_btn'] ); ?></a>
                </div><!-- .read-more -->
            <?php endif; ?>
            </div><!-- .travel-content-wrapper -->
        </article>

    <?php endforeach; ?>

    </div>

   <?php endif; ?>
    <?php
    }    
endif;