<?php
/**
 * Video section
 *
 * This is the template for the content of video section
 *
 * @package Theme Palace
 * @subpackage Blog Diary Pro
 * @since Blog Diary Pro 1.0.0
 */
if ( ! function_exists( 'blog_diary_pro_add_video_section' ) ) :
    /**
    * Add video section
    *
    *@since Blog Diary Pro 1.0.0
    */
    function blog_diary_pro_add_video_section() {
    	$options = blog_diary_pro_get_theme_options();
        // Check if video is enabled on frontpage
        $video_enable = apply_filters( 'blog_diary_pro_section_status', true, 'video_section_enable' );

        if ( true !== $video_enable ) {
            return false;
        }
        // Get video section details
        $section_details = array();
        $section_details = apply_filters( 'blog_diary_pro_filter_video_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render video section now.
        blog_diary_pro_render_video_section( $section_details );
    }
endif;

if ( ! function_exists( 'blog_diary_pro_get_video_section_details' ) ) :
    /**
    * video section details.
    *
    * @since Blog Diary Pro 1.0.0
    * @param array $input video section details.
    */
    function blog_diary_pro_get_video_section_details( $input ) {
        $options = blog_diary_pro_get_theme_options();

        // Content type.
        $video_content_type  = $options['video_content_type'];
        
        $content = array();
        switch ( $video_content_type ) {
        	
            case 'custom':
                $custom['title']        = ! empty( $options['video_title'] ) ? $options['video_title'] : '';
                $custom['excerpt']      = ! empty( $options['video_description'] ) ? $options['video_description'] : '';

                // Push to the main array.
                array_push( $content, $custom );
            break;

            case 'page':
                $page_id = ! empty( $options['video_content_page'] ) ? $options['video_content_page'] : '';
                $args = array(
                    'post_type'         => 'page',
                    'page_id'           => $page_id,
                    'posts_per_page'    => 1,
                    );                    
            break;

            case 'post':
                $post_id = ! empty( $options['video_content_post'] ) ? $options['video_content_post'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'p'                 => $post_id,
                    'posts_per_page'    => 1,
                    );
            break;

            default:
            break;
        }

        if ( 'custom' !== $video_content_type ) :
            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = blog_diary_pro_trim_content( 25 );

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
        endif;
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// video section content details.
add_filter( 'blog_diary_pro_filter_video_section_details', 'blog_diary_pro_get_video_section_details' );


if ( ! function_exists( 'blog_diary_pro_render_video_section' ) ) :
  /**
   * Start video section
   *
   * @return string video content
   * @since Blog Diary Pro 1.0.0
   *
   */
   function blog_diary_pro_render_video_section( $content_details = array() ) {
        $options = blog_diary_pro_get_theme_options();
        $image = ( ! empty( $options['video_image'] ) ) ? $options['video_image'] : '' ;

        if ( empty( $content_details ) ) {
            return;
        } 
        if ( $options['home_layout'] == 'third-design' || $options['home_layout'] == 'fifth-design' || $options['home_layout'] == 'eight-design' || $options['home_layout'] == 'nine-design' ): 

        ?>

        <?php foreach ( $content_details as $content ) :  ?>
        <div id="business-video" class="page-section" style="background-image: url('<?php echo esc_url( $image ); ?>');">
                <div class="wrapper">
                    <div class="business-section-header">
                    <?php if ( ! empty( $content['title'] ) ) : ?>
                        <h2 class="business-section-title"><?php echo esc_html( $content['title'] ); ?></h2>
                    <?php endif; ?>

                    <?php if ( ! empty( $content['excerpt'] ) ) : ?>
                        <p class="business-section-subtitle"><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                    <?php endif; ?>
                    </div><!-- .business-section-header -->

                    <?php if(!empty( $options['video_link'] ) ): ?>
                    <div class="business-section-content">
                        <div class="video-button">
                            <a href="<?php echo esc_url( $options['video_link'] ); ?>" class="popup-youtube">
                            <?php echo blog_diary_pro_get_svg( array( 'icon' => 'play' ) ); ?>
                            </a>
                        </div><!-- .video-button -->
                    </div><!-- .section-content -->
                <?php endif; ?>
                </div><!-- .wrapper -->
            </div>
        <?php endforeach; 

        endif;

            }
endif;

